@@ -1,7 +1,7 @@
 //! VM parameters
 
 use fuel_tx::consts::*;
-use fuel_types::{Bytes32, Color, Word};
+use fuel_types::{AssetId, Bytes32, Word};
 
 use std::mem;
 
@@ -87,8 +87,8 @@ pub const VM_REGISTER_WIDTH: u8 = 6;
 pub const VM_TX_MEMORY: usize = Bytes32::LEN // Tx ID
             + WORD_SIZE // Tx size
             + MAX_INPUTS as usize * (
-                Color::LEN + WORD_SIZE
-                ); // Color/Balance coin input pairs
+                AssetId::LEN + WORD_SIZE
+                ); // Asset ID/Balance coin input pairs
 
 /// Empty merkle root for receipts tree
 pub const EMPTY_RECEIPTS_MERKLE_ROOT: [u8; 32] = [
